package com.jiuqi.sql.impl;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.jiuqi.sql.DBException;
import com.jiuqi.sql.FieldInfo;
import com.jiuqi.sql.InputRecordBuffer;
import com.jiuqi.sql.impl.DBaseFileTail;
import com.jiuqi.sql.impl.RW;
import java.io.IOException;
import java.io.InputStream;
import java.util.Date;

public class DBaseInputRecordBuffer implements InputRecordBuffer {
  private char deleteFlag;
  
  private byte[] buffer;
  
  private boolean prevNull;
  
  private DBaseFileTail strValueList;
  
  private boolean supportText;
  
  public DBaseInputRecordBuffer(int recordSize, boolean supportText, DBaseFileTail strValueList) {
    this.buffer = new byte[recordSize];
    this.supportText = supportText;
    this.strValueList = strValueList;
  }
  
  public boolean readRecord(InputStream stream) throws DBException {
    boolean result = false;
    try {
      this.deleteFlag = (char)stream.read();
      if (!this.supportText || this.deleteFlag != '\032') {
        int readSize = stream.read(this.buffer);
        result = (readSize == this.buffer.length);
      } 
    } catch (IOException ex) {
      DBException dbe = new DBException();
      dbe.setStackTrace(ex.getStackTrace());
      throw dbe;
    } 
    return result;
  }
  
  public boolean isDeleted() {
    return (this.deleteFlag == '*');
  }
  
  private boolean isNull(FieldInfo info) {
    boolean flag;
    int j;
    int empty;
    int i;
    int size;
    int k;
    switch (info.type) {
      case 1:
        return (this.buffer[info.offset] == 32);
      case 3:
        flag = false;
        for (j = 0; j < 8; j++) {
          if (this.buffer[info.offset + j] != 0) {
            flag = true;
            break;
          } 
        } 
        return !flag;
      case 5:
        flag = false;
        for (j = 0; j < 4; j++) {
          if (this.buffer[info.offset + j] != 0) {
            flag = true;
            break;
          } 
        } 
        return !flag;
      case 6:
        flag = false;
        empty = 0;
        size = info.size;
        if (this.supportText) {
          empty = -1;
          size = 4;
        } 
        for (k = 0; k < size; k++) {
          if (this.buffer[info.offset + k] != empty) {
            flag = true;
            break;
          } 
        } 
        return !flag;
      case 2:
      case 8:
        flag = false;
        for (i = 0; i < 8; i++) {
          if (this.buffer[info.offset + i] != 32) {
            flag = true;
            break;
          } 
        } 
        return !flag;
    } 
    return false;
  }
  
  public boolean readBoolean(FieldInfo info) throws DBException {
    this.prevNull = isNull(info);
    return this.prevNull ? false : RW.readBoolean(this.buffer, info.offset);
  }
  
  public double readDouble(FieldInfo info) throws DBException {
    this.prevNull = isNull(info);
    return this.prevNull ? 0.0D : RW.readDouble(this.buffer, info.offset);
  }
  
  public int readInt(FieldInfo info) throws DBException {
    this.prevNull = isNull(info);
    return this.prevNull ? 0 : RW.readInt(this.buffer, info.offset);
  }
  
  public String readString(FieldInfo info) throws DBException {
    this.prevNull = isNull(info);
    if (this.prevNull)
      return null; 
    if (this.supportText) {
      int index = RW.readInt(this.buffer, info.offset);
      return this.strValueList.get(index);
    } 
    return RW.readString(this.buffer, info.offset, info.size);
  }
  
  public long readLong(FieldInfo info) throws DBException {
    this.prevNull = isNull(info);
    return this.prevNull ? 0L : RW.readLong(this.buffer, info.offset);
  }
  
  public Date readDate(FieldInfo info) throws DBException {
    this.prevNull = isNull(info);
    return this.prevNull ? null : RW.readDateTime(this.buffer, info.offset);
  }
  
  public boolean wasNull() throws DBException {
    return this.prevNull;
  }
}
